# abortion_policies
Easy to read abortion policies from the abortion policy API

This code is built using the [AbortionPolicyAPI](https://www.abortionpolicyapi.com/)

## Installation
If you want to install and run the code yourself you will first need an API key. You can apply for an API key here:

[AbortionPolicyAPI](https://www.abortionpolicyapi.com/request-access)

Once you have an API token you can pip install this application

```console
pip install abortion_policies
```

## Running the code
Then you can run the software and supply your API token

```console
abortion_policies 

Abortion API Token: <supply token>
```

Then you can review the output

## Consuming the Code
If you simply want to consume the output from the API you can Git clone the repository locally which will include all of the generated documents

```console
git clone https://github.com/automateyournetwork/abortion_policies
```
### VS Code Extensions
You can use VS Code to browse and view all of the various file types using the following extensions 
#### Excel Preview
Used to preview the CSV files 
#### Markdown Preview
Used to preview the markdown files
#### Markmap
Used to preview and generate the mind maps
#### Open in Default Browser
Used to view the HTML data tables and SVG files 
(Right click on the file, select Open in Default Browser)

#### Audio-preview
Used to listen to the MP3 files